"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.askConfirmation = exports.registerCommand = exports.notify = exports.notifier = void 0;

var _updateNotifier = _interopRequireDefault(require("update-notifier"));

var _prettyError = _interopRequireDefault(require("pretty-error"));

var _caporal = _interopRequireDefault(require("caporal"));

var _inquirer = _interopRequireDefault(require("inquirer"));

var _pTry = _interopRequireDefault(require("p-try"));

var _package = _interopRequireDefault(require("../../package.json"));

var _initialized = _interopRequireDefault(require("../actions/initialized"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const pe = new _prettyError.default();
pe.appendStyle({
  'pretty-error > trace > item': {
    marginBottom: 0
  }
});
const notifier = (0, _updateNotifier.default)({
  pkg: _package.default
});
exports.notifier = notifier;

const notify = () => notifier.notify();

exports.notify = notify;

const registerCommand = ({
  name,
  alias,
  description,
  initialization,
  action,
  args = [],
  opts = []
}) => {
  const command = _caporal.default.command(name, description);

  if (alias) {
    command.alias(alias);
  }

  args.forEach(argument => {
    command.argument(...argument);
  });
  opts.forEach(option => {
    command.option(...option);
  });
  command.action((args, options, logger) => {
    if (initialization && !(0, _initialized.default)()) {
      logger.info('Cloud link not initialized! run `cloud-link init` first');
      return;
    }

    return (0, _pTry.default)(() => action({
      args,
      options,
      logger
    })).then(() => {
      notify();
    }).catch(error => {
      console.error(pe.render(error));
    });
  });
};

exports.registerCommand = registerCommand;

const askConfirmation = ({
  shouldAsk = true,
  message,
  action
}) => {
  if (!shouldAsk) {
    return action();
  }

  return _inquirer.default.prompt([{
    type: 'confirm',
    name: 'confirm',
    message,
    default: false
  }]).then(({
    confirm
  }) => confirm && action());
};

exports.askConfirmation = askConfirmation;
//# sourceMappingURL=util.js.map